@@ -1,10 +1,10 @@
 from pilottai.core.base_agent import BaseAgent
-from pilottai.core.base_task import BaseTask
+from pilottai.core.base_job import BaseJob
 from pilottai.core.base_config import *
 
 __all__ = [
     'BaseAgent',
-    'BaseTask',
+    'BaseJob',
     'LLMConfig',
     'ServeConfig',
     'AgentConfig',
