@@ -1,16 +1,16 @@
 from pilottai.enums.health_e import HealthStatus
 from pilottai.enums.process_e import ProcessType
-from pilottai.enums.role_e import AgentRole
+from pilottai.enums.type_e import AgentType
 from pilottai.enums.agent_e import AgentStatus
-from pilottai.enums.task_e import TaskPriority, TaskStatus
+from pilottai.enums.job_e import JobPriority, JobStatus
 from pilottai.enums.tool_e import ToolStatus
 
 __all__ = [
     'HealthStatus',
     'ProcessType',
-    'AgentRole',
+    'AgentType',
     'AgentStatus',
-    'TaskPriority',
-    'TaskStatus',
+    'JobPriority',
+    'JobStatus',
     'ToolStatus',
 ]
