@@ -1,7 +1,7 @@
 from enum import Enum
 
 class ProcessType(str, Enum):
-    """Processing type for task execution"""
+    """Processing type for job execution"""
     SEQUENTIAL = "sequential"
     PARALLEL = "parallel"
     HIERARCHICAL = "hierarchical"
